@@ -1,4 +1,3 @@
-import os
 import shutil
 import tempfile
 from typing import Tuple, Optional
@@ -17,9 +16,7 @@ class NapiPy:
     def calc_hash(self, movie: str) -> str:
         return calc_movie_hash_as_hex(movie)
 
-    def download_subs(
-        self, movie_hash: str, use_enc: Optional[str] = None
-    ) -> Tuple[Optional[str], Optional[str], Optional[str]]:
+    def download_subs(self, movie_hash: str, use_enc: Optional[str] = None) -> Tuple[Optional[str], Optional[str], Optional[str]]:
         subs_bin = un7zip_api_response(download_for(movie_hash))
         if subs_bin:
             src_enc, subs_utf8 = decode_subs(subs_bin, use_enc=use_enc)
@@ -31,11 +28,9 @@ class NapiPy:
 
     def move_subs_to_movie(self, tmp_subs: str, movie: str) -> str:
         tgt_path = get_target_path_for_subtitle(movie)
-        shutil.copy(tmp_subs, tgt_path)
-        os.remove(tmp_subs)
+        shutil.move(tmp_subs, tgt_path)
         return tgt_path
 
     def move_subs(self, tmp_subs: str, path: str) -> str:
-        shutil.copy(tmp_subs, path)
-        os.remove(tmp_subs)
+        shutil.move(tmp_subs, path)
         return path
